// ===========================================================================
// CONTENT  : INTERFACE OAuth2Constants
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 29/12/2016
// HISTORY  :
//  29/12/2016  mdu  CREATED
//
// Copyright (c) 2016, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.oauth;

/**
 * Constants useful in the context of OAuth2.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public interface OAuth2Constants
{
  // ===========================================================================
  // RFC6749 
  // ===========================================================================
  public static final String GRANT_TYPE = "grant_type";
  public static final String CLIENT_ID = "client_id";
  public static final String CLIENT_SECRET = "client_secret";
  public static final String ACCESS_TOKEN = "access_token";
  public static final String REFRESH_TOKEN = "refresh_token";
  public static final String CODE = "code";
  public static final String SCOPE = "scope";
  public static final String STATE = "state";
  public static final String TOKEN_TYPE = "token_type";
  public static final String RESPONSE_TYPE = "response_type";
  public static final String REDIRECT_URI = "redirect_uri";

  // ===========================================================================
  // OAuth Token Introspection Request (RFC7662)
  // ===========================================================================
  public static final String TI_REQ_PARAM_TOKEN = "token"; // REQUIRED. The string value of the token, "[RFC7662, Section 2.1]"
  public static final String TI_REQ_PARAM_TOKEN_TYPE_HINT = "token_type_hint"; // OPTIONAL.  A hint about the type of the token submitted for introspection., "[RFC7662, Section 2.1]"

  public static final String TOKEN_TYPE_HINT_ACCESS_TOKEN = "access_token";
  public static final String TOKEN_TYPE_HINT_REFRESH_TOKEN = "refresh_token";  
  
  // ===========================================================================
  // OAuth Token Introspection Response (RFC7662)
  // ===========================================================================
  public static final String TI_RESP_FIELD_ACTIVE = "active"; // Token active status,IESG,"[RFC7662, Section 2.2]"
  public static final String TI_RESP_FIELD_USERNAME = "username"; // User identifier of the resource owner,IESG,"[RFC7662, Section 2.2]"
  public static final String TI_RESP_FIELD_CLIENT_ID = "client_id"; //Client identifier of the client,IESG,"[RFC7662, Section 2.2]"
  public static final String TI_RESP_FIELD_SCOPE = "scope"; // Authorized scopes of the token,IESG,"[RFC7662, Section 2.2]"
  public static final String TI_RESP_FIELD_TOKEN_TYPE = "token_type"; //Type of the token,IESG,"[RFC7662, Section 2.2]"
  public static final String TI_RESP_FIELD_EXPIRATION = "exp"; // Expiration timestamp of the token,IESG,"[RFC7662, Section 2.2]"
  public static final String TI_RESP_FIELD_ISSUED_AT = "iat"; // Issuance timestamp of the token,IESG,"[RFC7662, Section 2.2]"
  public static final String TI_RESP_FIELD_NOT_BEFORE = "nbf"; // Timestamp which the token is not valid before,IESG,"[RFC7662, Section 2.2]"
  public static final String TI_RESP_FIELD_SUBJECT = "sub"; // Subject of the token,IESG,"[RFC7662, Section 2.2]"
  public static final String TI_RESP_FIELD_AUDIENCE = "aud"; // Audience of the token,IESG,"[RFC7662, Section 2.2]"
  public static final String TI_RESP_FIELD_ISSUER = "iss"; // Issuer of the token,IESG,"[RFC7662, Section 2.2]"
  public static final String TI_RESP_FIELD_JTI = "jti"; // Unique identifier of the token,IESG,"[RFC7662, Section 2.2]"

  public static final String DEFAULT_URI_SUFFIX_TOKEN_INTROSPECTION_REQUEST = "/introspect"; // non-normative example from [RFC7662, Section 2.1]
}