// ===========================================================================
// CONTENT  : CLASS TokenIntrospectionResult
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 08/01/2017
// HISTORY  :
//  08/01/2017  mdu  CREATED
//
// Copyright (c) 2017, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.oauth;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.io.Serializable;

/**
 * Contains the data of a OAuth2 token introspection request according to
 * https://tools.ietf.org/html/rfc7662 section 2.2
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class TokenIntrospectionResult implements Serializable
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  private static final long serialVersionUID = 1693062981250576315L;
  
  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private boolean active;
  private String clientId;
  private String username;
  private String issuer;
  private String tokenType;
  private String subject;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  public TokenIntrospectionResult()
  {
    super();
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public boolean isActive()
  {
    return this.active;
  }
  
  public void setActive(boolean active)
  {
    this.active = active;
  }

  public String getClientId()
  {
    return this.clientId;
  }

  public void setClientId(String clientId)
  {
    this.clientId = clientId;
  }

  public String getUsername()
  {
    return this.username;
  }

  public void setUsername(String username)
  {
    this.username = username;
  }

  public String getIssuer()
  {
    return this.issuer;
  }

  public void setIssuer(String issuer)
  {
    this.issuer = issuer;
  }

  public String getTokenType()
  {
    return this.tokenType;
  }

  public void setTokenType(String tokenType)
  {
    this.tokenType = tokenType;
  }

  public String getSubject()
  {
    return this.subject;
  }

  public void setSubject(String subject)
  {
    this.subject = subject;
  }
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================

}
