// ===========================================================================
// CONTENT  : CLASS TokenIntrospectionResultConverter
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 08/01/2017
// HISTORY  :
//  08/01/2017  mdu  CREATED
//
// Copyright (c) 2017, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.oauth;

// ===========================================================================
// IMPORTS
// ===========================================================================
import static org.pfsw.oauth.OAuth2Constants.*;

import org.pfsw.text.json.JsonObject;
import org.pfsw.text.json.JsonObjectAccessor;

/**
 * A converter that creates a TokenIntrospectionResult from a given JSON object.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class TokenIntrospectionResultConverter
{
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  public TokenIntrospectionResultConverter()
  {
    super();
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Converts the given JsonObject to a JSON web Token (JWT) according to the
   * OpenID Connect Core 1.0 specification, section 2.  ID Token.
   * 
   * @param jsonObject An object that must at least contain the required ID Token claims. 
   * @return The JWT containing all data from the provided JsonObject.
   * @throws ConversionException In any case of missing claims or wrong data types. 
   */
  public TokenIntrospectionResult convertToInternal(final JsonObject jsonObject) throws ConversionException
  {
    TokenIntrospectionResult result;
    JsonObjectAccessor jsonAccessor;
    
    jsonAccessor = new JsonObjectAccessor(jsonObject);
    result = new TokenIntrospectionResult();
    
    try
    {      
      // REQUIRED
      result.setActive(jsonAccessor.getRequiredBooleanValue(TI_RESP_FIELD_ACTIVE));
      
      // OPTIONAL
      result.setClientId(jsonAccessor.getOptionalStringValue(TI_RESP_FIELD_CLIENT_ID));
      result.setUsername(jsonAccessor.getOptionalStringValue(TI_RESP_FIELD_USERNAME));
      result.setIssuer(jsonAccessor.getOptionalStringValue(TI_RESP_FIELD_ISSUER));
      result.setSubject(jsonAccessor.getOptionalStringValue(TI_RESP_FIELD_SUBJECT));
      result.setTokenType(jsonAccessor.getOptionalStringValue(TI_RESP_FIELD_TOKEN_TYPE));
      
      return result;
    }
    catch (RuntimeException e)
    {
      throw new ConversionException("Unable to convert the given JSON object to a TokenIntrospectionResult: " + e, e);
    }
  }
}
