// ===========================================================================
// CONTENT  : ABSTRACT CLASS LoggerProvider
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 11/10/2014
// HISTORY  :
//  11/10/2014  mdu  CREATED
//
// Copyright (c) 2014, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.oidc.internal;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pfsw.logging.Logger2Logger;
import org.pfsw.logging.LoggerFactory;
import org.pfsw.logging.LoggerFactoryProvider;

/**
 * A single point of access to the logging capabilities of this component.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
abstract public class LoggerProvider
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  private static final String COMPONENT_LOGGER_ID = "org.pfsw.oidc";
  private static final Logger2Logger LOGGER = createComponentLogger();
  
  public static final String PFOIDC0001 = "PFOIDC0001";
  public static final String PFOIDC0002 = "PFOIDC0002";
  public static final String PFOIDC0003 = "PFOIDC0003";
  public static final String PFOIDC0004 = "PFOIDC0004";
  public static final String PFOIDC0005 = "PFOIDC0005";

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================

  // =========================================================================
  // CLASS METHODS
  // =========================================================================
  public static Logger2Logger getComponentLogger() 
  {
    return LOGGER;
  } // getComponentLogger() 
  
  // -------------------------------------------------------------------------

  private static Logger2Logger createComponentLogger() 
  {
    LoggerFactory loggerFactory;
    
    loggerFactory = LoggerFactoryProvider.getLoggerFactory();
    return new Logger2Logger(loggerFactory.getLogger(COMPONENT_LOGGER_ID));
  }
  
  // -------------------------------------------------------------------------
  
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  private LoggerProvider()
  {
    super();
  } // LoggerProvider()

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================

} // class LoggerProvider
